@@ -1,9 +1,7 @@
 use crypto_market_type::MarketType;
+use crypto_msg_type::MessageType;
 
-use crate::{
-    exchanges::utils::calc_quantity_and_volume, MessageType, Order, OrderBookMsg, TradeMsg,
-    TradeSide,
-};
+use crate::{exchanges::utils::calc_quantity_and_volume, Order, OrderBookMsg, TradeMsg, TradeSide};
 
 use serde::{Deserialize, Serialize};
 use serde_json::{Result, Value};
