@@ -2,11 +2,10 @@ pub mod exchanges;
 mod msg;
 mod order;
 
+use crypto_market_type::MarketType;
 pub use msg::*;
 pub use order::Order;
 
-pub use crypto_market_type::MarketType;
-
 use serde_json::Result;
 
 /// Extract the symbol from the message.
